@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -22,8 +22,7 @@
 
 #include <sonnet/highlighter.h>
 #include "kpimtextedit_export.h"
-namespace KPIMTextEdit
-{
+namespace KPIMTextEdit {
 class RichTextComposer;
 class KPIMTEXTEDIT_EXPORT RichTextComposerEmailQuoteHighlighter : public Sonnet::Highlighter
 {
@@ -34,14 +33,10 @@ public:
      * Constructor. See setQuoteColor() for the parameters.
      * FIXME: Default colors don't obey color scheme
      */
-    explicit RichTextComposerEmailQuoteHighlighter(RichTextComposer *textEdit,
-            const QColor &normalColor = Qt::black,
-            const QColor &quoteDepth1 = QColor(0x00, 0x80, 0x00),
-            const QColor &quoteDepth2 = QColor(0x00, 0x80, 0x00),
-            const QColor &quoteDepth3 = QColor(0x00, 0x80, 0x00),
-            const QColor &misspelledColor = Qt::red);
+    explicit RichTextComposerEmailQuoteHighlighter(RichTextComposer *textEdit, const QColor &normalColor = Qt::black, const QColor &quoteDepth1 = QColor(0x00, 0x80, 0x00),
+                                                   const QColor &quoteDepth2 = QColor(0x00, 0x80, 0x00), const QColor &quoteDepth3 = QColor(0x00, 0x80, 0x00), const QColor &misspelledColor = Qt::red);
 
-    ~RichTextComposerEmailQuoteHighlighter();
+    ~RichTextComposerEmailQuoteHighlighter() override;
 
     /**
      * Sets the colors used for highlighting quoted text and spelling mistakes.
@@ -53,11 +48,7 @@ public:
      * @param normalColor will be ignored, only provided for KNode
      *                    compatibility.
      */
-    void setQuoteColor(const QColor &normalColor,
-                       const QColor &quoteDepth1,
-                       const QColor &quoteDepth2,
-                       const QColor &quoteDepth3,
-                       const QColor &misspelledColor = Qt::red);
+    void setQuoteColor(const QColor &normalColor, const QColor &quoteDepth1, const QColor &quoteDepth2, const QColor &quoteDepth3, const QColor &misspelledColor = Qt::red);
 
     /**
      * Turns spellcheck highlighting on or off.
@@ -69,7 +60,7 @@ public:
     /**
      * Reimplemented to highlight quote blocks.
      */
-    void highlightBlock(const QString &text) Q_DECL_OVERRIDE;
+    void highlightBlock(const QString &text) override;
 protected:
 
     /**
@@ -79,19 +70,18 @@ protected:
      * @param start the beginning of text
      * @param count the amount of characters to set
      */
-    void unsetMisspelled(int start, int count) Q_DECL_OVERRIDE;
+    void unsetMisspelled(int start, int count) override;
 
     /**
      * Reimplemented to set the color of the misspelled word to a color
      * defined by setQuoteColor().
      */
-    void setMisspelled(int start, int count) Q_DECL_OVERRIDE;
+    void setMisspelled(int start, int count) override;
 
 private:
     class RichTextComposerEmailQuoteHighlighterPrivate;
     RichTextComposerEmailQuoteHighlighterPrivate *const d;
 };
-
 }
 
 #endif // RICHTEXTCOMPOSEREMAILQUOTEHIGHLIGHTER_H
