@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -109,8 +109,8 @@ void TableCellFormatDialog::setTableCellBackgroundColor(const QColor &col)
 QTextCharFormat::VerticalAlignment TableCellFormatDialog::verticalAlignment() const
 {
     return
-        (QTextCharFormat::VerticalAlignment)d->verticalAlignment->itemData(
-        d->verticalAlignment->currentIndex()).toInt();
+        static_cast<QTextCharFormat::VerticalAlignment>(d->verticalAlignment->itemData(
+        d->verticalAlignment->currentIndex()).toInt());
 }
 
 void TableCellFormatDialog::setVerticalAlignment(QTextCharFormat::VerticalAlignment vertical)
